Deferring tasks.

- [X] tasks, sections, and files marked `@after` should not appear in the
      default output until all other tasks are complete
- [X] `--guide` to output just what the Markdown formatting is
